Index: tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/messages/SpecificitiesUIMessages.java
===================================================================
--- tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/messages/SpecificitiesUIMessages.java	(revision 938)
+++ tmp/org.txm.specificities.rcp/src/org/txm/specificities/rcp/messages/SpecificitiesUIMessages.java	(revision 939)
@@ -3,8 +3,16 @@
 import org.eclipse.osgi.util.NLS;
 import org.txm.utils.messages.Utf8NLS;
 
+/**
+ * Specificities UI messages.
+ * 
+ * @author sjacquot
+ *
+ */
 public class SpecificitiesUIMessages extends NLS {
 	
+	private static final String BUNDLE_NAME = "org.txm.specificities.rcp.messages.messages"; //$NON-NLS-1$
+	
 	public static String SpecificitiesPreferencePage_2;
 	public static String SpecificitiesPreferencePage_3;
 	public static String SpecificitiesPreferencePage_4;
@@ -18,7 +26,7 @@
 	
 	static {
 		// initialize resource bundle
-		Utf8NLS.initializeMessages(SpecificitiesUIMessages.class);
+		Utf8NLS.initializeMessages(BUNDLE_NAME, SpecificitiesUIMessages.class);
 	}
 
 	private SpecificitiesUIMessages() {
Index: tmp/org.txm.treetagger.rcp/src/org/txm/treetagger/rcp/messages/TreeTaggerUIMessages.java
===================================================================
--- tmp/org.txm.treetagger.rcp/src/org/txm/treetagger/rcp/messages/TreeTaggerUIMessages.java	(revision 938)
+++ tmp/org.txm.treetagger.rcp/src/org/txm/treetagger/rcp/messages/TreeTaggerUIMessages.java	(revision 939)
@@ -13,6 +13,8 @@
  */
 public class TreeTaggerUIMessages extends NLS {
 
+	private static final String BUNDLE_NAME = "org.txm.treetagger.rcp.messages.messages"; //$NON-NLS-1$
+	
 	public static String TreeTaggerPreferencePage_0;
 	public static String TreeTaggerPreferencePage_1;
 	public static String TreeTaggerPreferencePage_2;
@@ -20,7 +22,7 @@
 	
 	static {
 		// initialize resource bundle
-		Utf8NLS.initializeMessages(TreeTaggerUIMessages.class);
+		Utf8NLS.initializeMessages(BUNDLE_NAME, TreeTaggerUIMessages.class);
 	}
 
 	private TreeTaggerUIMessages() {
Index: tmp/org.txm.utils/src/org/txm/utils/messages/UtilsCoreMessages.java
===================================================================
--- tmp/org.txm.utils/src/org/txm/utils/messages/UtilsCoreMessages.java	(revision 938)
+++ tmp/org.txm.utils/src/org/txm/utils/messages/UtilsCoreMessages.java	(revision 939)
@@ -11,6 +11,8 @@
  */
 public class UtilsCoreMessages extends NLS {
 
+	private static final String BUNDLE_NAME = "org.txm.utils.messages.messages"; //$NON-NLS-1$
+	
 	public static String ExecTimer_0;
 	public static String ExecTimer_1;
 	public static String ExecTimer_2;
@@ -34,6 +36,6 @@
 	
 	static {
 		// initialize resource bundle
-		Utf8NLS.initializeMessages(UtilsCoreMessages.class);
+		Utf8NLS.initializeMessages(BUNDLE_NAME, UtilsCoreMessages.class);
 	}
 }
Index: tmp/org.txm.statsengine.r.rcp/src/org/txm/statsengine/r/rcp/messages/RUIMessages.java
===================================================================
--- tmp/org.txm.statsengine.r.rcp/src/org/txm/statsengine/r/rcp/messages/RUIMessages.java	(revision 938)
+++ tmp/org.txm.statsengine.r.rcp/src/org/txm/statsengine/r/rcp/messages/RUIMessages.java	(revision 939)
@@ -3,8 +3,16 @@
 import org.eclipse.osgi.util.NLS;
 import org.txm.utils.messages.Utf8NLS;
 
+/**
+ * R statistics engine UI messages.
+ * 
+ * @author sjacquot
+ *
+ */
 public class RUIMessages extends NLS {
 
+	private static final String BUNDLE_NAME = "org.txm.statsengine.r.rcp.messages.messages"; //$NON-NLS-1$
+	
 	public static String RPreferencePage_0;
 	public static String RPreferencePage_1;
 	public static String RPreferencePage_2;
@@ -57,7 +65,7 @@
 
 	static {
 		// initialize resource bundle
-		Utf8NLS.initializeMessages( RUIMessages.class);
+		Utf8NLS.initializeMessages(BUNDLE_NAME, RUIMessages.class);
 	}
 
 	private RUIMessages() {
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/ApplicationActionBarAdvisor.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/ApplicationActionBarAdvisor.java	(revision 938)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/ApplicationActionBarAdvisor.java	(revision 939)
@@ -29,7 +29,6 @@
 
 import org.eclipse.jface.action.ICoolBarManager;
 import org.eclipse.jface.action.IMenuManager;
-import org.eclipse.swt.widgets.Display;
 import org.eclipse.ui.IWorkbenchWindow;
 import org.eclipse.ui.actions.ActionFactory;
 import org.eclipse.ui.actions.ActionFactory.IWorkbenchAction;
@@ -45,7 +44,7 @@
 
 // TODO: Auto-generated Javadoc
 /**
- * Controls the availables commands in toolbar
+ * Controls the available commands in toolbar
  */
 @Deprecated
 public class ApplicationActionBarAdvisor extends ActionBarAdvisor {
@@ -71,21 +70,6 @@
 	/** The delete action. */
 	private IWorkbenchAction deleteAction;
 
-	/** The compute specificities. */
-	//private ComputeSpecificities computeSpecificities;
-
-	/** The get concordances. */
-	//private GetConcordances getConcordances;
-
-	//private CreatePartition createPartition;
-
-	//private CreateSubcorpus createSubcorpus;
-
-	/** The create frequency list. */
-	//private CreateFrequencyList createFrequencyList;
-
-	// private ComputeCorrespondanceAnalysis computeCorrespondanceAnalysis;
-
 	/** The import action. */
 	private RunGroovyScript importAction;
 
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/ApplicationWorkbenchWindowAdvisor.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/ApplicationWorkbenchWindowAdvisor.java	(revision 938)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/ApplicationWorkbenchWindowAdvisor.java	(revision 939)
@@ -47,8 +47,6 @@
 import org.eclipse.ui.application.IWorkbenchWindowConfigurer;
 import org.eclipse.ui.application.WorkbenchWindowAdvisor;
 import org.eclipse.ui.internal.WorkbenchWindow;
-import org.eclipse.ui.menus.AbstractContributionFactory;
-import org.eclipse.ui.menus.IMenuService;
 import org.txm.rcp.messages.TXMUIMessages;
 import org.txm.utils.logger.Log;
 
@@ -63,8 +61,7 @@
 	 *
 	 * @param configurer the configurer
 	 */
-	public ApplicationWorkbenchWindowAdvisor(
-			IWorkbenchWindowConfigurer configurer) {
+	public ApplicationWorkbenchWindowAdvisor(IWorkbenchWindowConfigurer configurer) {
 		super(configurer);
 	}
 
@@ -72,8 +69,7 @@
 	 * @see org.eclipse.ui.application.WorkbenchWindowAdvisor#createActionBarAdvisor(org.eclipse.ui.application.IActionBarConfigurer)
 	 */
 	@Override
-	public ActionBarAdvisor createActionBarAdvisor(
-			IActionBarConfigurer configurer) {
+	public ActionBarAdvisor createActionBarAdvisor(IActionBarConfigurer configurer) {
 		return new ApplicationActionBarAdvisor(configurer);
 	}
 
Index: tmp/org.txm.rcp/src/main/java/org/txm/rcp/ApplicationWorkbenchAdvisor.java
===================================================================
--- tmp/org.txm.rcp/src/main/java/org/txm/rcp/ApplicationWorkbenchAdvisor.java	(revision 938)
+++ tmp/org.txm.rcp/src/main/java/org/txm/rcp/ApplicationWorkbenchAdvisor.java	(revision 939)
@@ -53,9 +53,7 @@
 import org.eclipse.jface.preference.PreferenceManager;
 import org.eclipse.jface.util.Util;
 import org.eclipse.osgi.util.NLS;
-import org.eclipse.swt.SWT;
 import org.eclipse.swt.graphics.Color;
-import org.eclipse.swt.widgets.DirectoryDialog;
 import org.eclipse.swt.widgets.Display;
 import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Shell;
@@ -86,9 +84,7 @@
 import org.txm.Toolbox;
 import org.txm.core.preferences.TBXPreferences;
 import org.txm.core.preferences.TXMPreferences;
-import org.txm.importer.Convert5To6;
 import org.txm.objects.Base;
-import org.txm.objects.Workspace;
 import org.txm.rcp.commands.OpenWelcomePage;
 import org.txm.rcp.commands.RestartTXM;
 import org.txm.rcp.commands.workspace.LoadBinaryCorpus;
@@ -102,7 +98,6 @@
 import org.txm.rcp.utils.JobHandler;
 import org.txm.rcp.views.corpora.CorporaView;
 import org.txm.searchengine.core.SearchEnginesManager;
-import org.txm.searchengine.cqp.CQPSearchEngine;
 import org.txm.utils.BundleUtils;
 import org.txm.utils.DeleteDir;
 import org.txm.utils.logger.Log;
@@ -122,8 +117,7 @@
 	 * @see org.eclipse.ui.application.WorkbenchAdvisor#createWorkbenchWindowAdvisor(org.eclipse.ui.application.IWorkbenchWindowConfigurer)
 	 */
 	@Override
-	public WorkbenchWindowAdvisor createWorkbenchWindowAdvisor(
-			IWorkbenchWindowConfigurer configurer) {
+	public WorkbenchWindowAdvisor createWorkbenchWindowAdvisor(IWorkbenchWindowConfigurer configurer) {
 		return new ApplicationWorkbenchWindowAdvisor(configurer);
 	}
 
Index: tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/messages_ru.properties
===================================================================
--- tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/messages_ru.properties	(revision 938)
+++ tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/messages_ru.properties	(revision 939)
@@ -1,18 +1,10 @@
 
-ReferencerEditor_0  = Расчет ссылок <{0}> в {1} с приоритетом {2} по шаблону {3}
-ReferencerEditor_10 = Получение индексов
 ReferencerEditor_11 = Ссылки
-ReferencerEditor_12 = Группировка позиций по индексам
-ReferencerEditor_13 = Обновление интерфейса
 ReferencerEditor_17 = Показ первой страницы результатов 
 ReferencerEditor_19 = Показ последней страницы результатов 
 ReferencerEditor_21 = Показ следующей страницы результатов 
 ReferencerEditor_23 = Показ предыдущей страницы результатов 
-ReferencerEditor_25 = Открытие конкорданса
-ReferencerEditor_5  = Расчет ссылок {0}
 ReferencerEditor_6  = Шаблон ссылок 
-ReferencerEditor_7  = Ни одного результата
-ReferencerEditor_8  = Получение употреблений
 
 ReferencerPreferencePage_2 = Ссылки
 ReferencerPreferencePage_3 = Сортировать ссылки по частотности
Index: tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/messages_fr.properties
===================================================================
--- tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/messages_fr.properties	(revision 938)
+++ tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/messages_fr.properties	(revision 939)
@@ -1,18 +1,10 @@
 ﻿
-ReferencerEditor_0  = Calcul des références de <{0}> dans {1} avec la propriété {2} et le patron {3}
-ReferencerEditor_10 = Récupération des index
 ReferencerEditor_11 = Références
-ReferencerEditor_12 = Regroupement des positions par index
-ReferencerEditor_13 = Mise à jour de l'interface
 ReferencerEditor_17 = Affichage de la première page de résultats
 ReferencerEditor_19 = Affichage de la dernière page de résultats
 ReferencerEditor_21 = Affichage de la page de résultats suivante 
 ReferencerEditor_23 = Affichage de la page de résultats précédente 
-ReferencerEditor_25 = Ouverture de la concordance
-ReferencerEditor_5  = Calcul des références de {0}
 ReferencerEditor_6  = Patron des références 
-ReferencerEditor_7  = Aucun résultat
-ReferencerEditor_8  = Récupération des occurrences
 
 ReferencerPreferencePage_2 = Références
 ReferencerPreferencePage_3 = Ordonner les références par fréquence
Index: tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/messages.properties
===================================================================
--- tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/messages.properties	(revision 938)
+++ tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/messages.properties	(revision 939)
@@ -1,19 +1,10 @@
 
-ReferencerEditor_0  = Compute references of <{0}> in {1} with property {2} and pattern {3}
-ReferencerEditor_10 = Get indexes
 ReferencerEditor_11 = References
-ReferencerEditor_12 = Group positions by indexes
-ReferencerEditor_13 = Refresh ui
 ReferencerEditor_17 = Showing first result page
 ReferencerEditor_19 = Showing last result page
 ReferencerEditor_21 = Showing next result page
 ReferencerEditor_23 = Showing previous result page
-ReferencerEditor_25 = Opening concordances
-ReferencerEditor_5  = Computing references of {0}
 ReferencerEditor_6  = Reference pattern
-ReferencerEditor_7  = No results
-ReferencerEditor_8  = Get matches
-ReferencerEditor_9  = Units
 
 ReferencerPreferencePage_2 = Referencer
 ReferencerPreferencePage_3 = Order references by frequency
Index: tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/ReferencerUIMessages.java
===================================================================
--- tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/ReferencerUIMessages.java	(revision 938)
+++ tmp/org.txm.referencer.rcp/src/org/txm/referencer/rcp/messages/ReferencerUIMessages.java	(revision 939)
@@ -1,4 +1,3 @@
-
 package org.txm.referencer.rcp.messages;
 
 import org.eclipse.osgi.util.NLS;
@@ -13,26 +12,20 @@
  */
 public class ReferencerUIMessages extends NLS {
 	
-	public static String ReferencerEditor_0;
-	public static String ReferencerEditor_10;
+	private static final String BUNDLE_NAME = "org.txm.referencer.rcp.messages.messages"; //$NON-NLS-1$
+	
 	public static String ReferencerEditor_11;
-	public static String ReferencerEditor_12;
-	public static String ReferencerEditor_13;
 	public static String ReferencerEditor_17;
 	public static String ReferencerEditor_19;
 	public static String ReferencerEditor_21;
 	public static String ReferencerEditor_23;
-	public static String ReferencerEditor_25;
-	public static String ReferencerEditor_5;
 	public static String ReferencerEditor_6;
-	public static String ReferencerEditor_7;
-	public static String ReferencerEditor_8;
 	public static String ReferencerPreferencePage_2;
 	public static String ReferencerPreferencePage_3;
 
 	static {
 		// initialize resource bundle
-		Utf8NLS.initializeMessages(ReferencerUIMessages.class);
+		Utf8NLS.initializeMessages(BUNDLE_NAME, ReferencerUIMessages.class);
 	}
 
 	private ReferencerUIMessages() {
Index: tmp/org.txm.wordcloud.rcp/src/org/txm/wordcloud/rcp/messages/messages.properties
===================================================================
--- tmp/org.txm.wordcloud.rcp/src/org/txm/wordcloud/rcp/messages/messages.properties	(revision 938)
+++ tmp/org.txm.wordcloud.rcp/src/org/txm/wordcloud/rcp/messages/messages.properties	(revision 939)
@@ -1,15 +1,12 @@
-EditorToolBar_Draw=Compute
-EditorToolBar_fmin=Fmin: 
-EditorToolBar_Percent_of_rotated_labels=% of rotated labels: 
-EditorToolBar_Randomize_positions=Randomize positions
-EditorToolBar_vmax=Vmax: 
-Log_WordCloud_ready=WordCloud ready: 
-Log_Wrong_input_object=Wrong WordCloud input object
-PreferencePage_Minimal_frequency=Minimal frequency for used words
-PreferencePage_Number_of_used_words=Number of used words
-PreferencePage_Percent_of_rotated_words=Percent of rotated words
-PreferencePage_Random_word_positions=Random word positions
-WordCloudEditor_7=WordClouding...
-WordCloudEditor_8=Drawing in {0}
-WordCloudEditor_9=WordCloud refreshed
-EditorName=WordCloud
\ No newline at end of file
+
+EditorToolBar_Percent_of_rotated_labels = % of rotated labels: 
+EditorToolBar_Randomize_positions       = Randomize positions
+EditorToolBar_fmin                      = Fmin: 
+EditorToolBar_vmax                      = Vmax: 
+
+Log_WordCloud_ready = WordCloud ready: 
+
+PreferencePage_Minimal_frequency        = Minimal frequency for used words
+PreferencePage_Number_of_used_words     = Number of used words
+PreferencePage_Percent_of_rotated_words = Percent of rotated words
+PreferencePage_Random_word_positions    = Random word positions
Index: tmp/org.txm.wordcloud.rcp/src/org/txm/wordcloud/rcp/messages/WordCloudUIMessages.java
===================================================================
--- tmp/org.txm.wordcloud.rcp/src/org/txm/wordcloud/rcp/messages/WordCloudUIMessages.java	(revision 938)
+++ tmp/org.txm.wordcloud.rcp/src/org/txm/wordcloud/rcp/messages/WordCloudUIMessages.java	(revision 939)
@@ -3,30 +3,29 @@
 import org.eclipse.osgi.util.NLS;
 import org.txm.utils.messages.Utf8NLS;
 
+/**
+ * Word cloud UI messages.
+ * 
+ * @author sjacquot
+ *
+ */
 public class WordCloudUIMessages extends NLS {
 	
+	private static final String BUNDLE_NAME = "org.txm.wordcloud.rcp.messages.messages"; //$NON-NLS-1$
+	
 	public static String EditorToolBar_vmax;
 	public static String EditorToolBar_fmin;
 	public static String EditorToolBar_Percent_of_rotated_labels;
 	public static String EditorToolBar_Randomize_positions;
-	public static String EditorToolBar_Draw;
 	public static String Log_WordCloud_ready;
 	public static String PreferencePage_Number_of_used_words;
 	public static String PreferencePage_Minimal_frequency;
 	public static String PreferencePage_Percent_of_rotated_words;
 	public static String PreferencePage_Random_word_positions;
 
-	//FIXME: unused keys
-	public static String EditorName;
-	public static String Log_Wrong_input_object;
-	public static String WordCloudEditor_7;
-	public static String WordCloudEditor_8;
-	public static String WordCloudEditor_9;
-	//end of fixme
-	
 	static {
 		// initialize resource bundle
-		Utf8NLS.initializeMessages(WordCloudUIMessages.class);
+		Utf8NLS.initializeMessages(BUNDLE_NAME, WordCloudUIMessages.class);
 	}
 
 	private WordCloudUIMessages() {
Index: tmp/org.txm.wordcloud.rcp/src/org/txm/wordcloud/rcp/messages/messages_fr.properties
===================================================================
--- tmp/org.txm.wordcloud.rcp/src/org/txm/wordcloud/rcp/messages/messages_fr.properties	(revision 938)
+++ tmp/org.txm.wordcloud.rcp/src/org/txm/wordcloud/rcp/messages/messages_fr.properties	(revision 939)
@@ -1,15 +1,12 @@
-EditorToolBar_Draw=Calculer
-EditorToolBar_fmin=Fmin : 
-EditorToolBar_Percent_of_rotated_labels=% de labels verticaux : 
-EditorToolBar_Randomize_positions=Position aléatoire
-EditorToolBar_vmax=Vmax : 
-Log_WordCloud_ready=WordCloud est prêt : 
-Log_Wrong_input_object=Object non-compatible avec la fonctionnalité Nuage de mots
-PreferencePage_Minimal_frequency=Filtre en fréquence minimal des mots à utiliser
-PreferencePage_Number_of_used_words=Filtre en nombre de mots à utiliser
-PreferencePage_Percent_of_rotated_words=Pourcentage de mots verticaux
-PreferencePage_Random_word_positions=Position aléatoire des mots
-WordCloudEditor_7=Dessin en cours...
-WordCloudEditor_8=Sauvegarde dans le fichier {0} 
-WordCloudEditor_9=Rafraîchissement 
-EditorName=Nuage de mots
\ No newline at end of file
+
+EditorToolBar_Percent_of_rotated_labels = % de labels verticaux : 
+EditorToolBar_Randomize_positions       = Position aléatoire
+EditorToolBar_fmin                      = Fmin : 
+EditorToolBar_vmax                      = Vmax : 
+
+Log_WordCloud_ready = WordCloud est prêt : 
+
+PreferencePage_Minimal_frequency        = Filtre en fréquence minimal des mots à utiliser
+PreferencePage_Number_of_used_words     = Filtre en nombre de mots à utiliser
+PreferencePage_Percent_of_rotated_words = Pourcentage de mots verticaux
+PreferencePage_Random_word_positions    = Position aléatoire des mots
Index: tmp/org.txm.searchengine.cqp.rcp/src/org/txm/searchengine/cqp/rcp/messages/CQPUIMessages.java
===================================================================
--- tmp/org.txm.searchengine.cqp.rcp/src/org/txm/searchengine/cqp/rcp/messages/CQPUIMessages.java	(revision 938)
+++ tmp/org.txm.searchengine.cqp.rcp/src/org/txm/searchengine/cqp/rcp/messages/CQPUIMessages.java	(revision 939)
@@ -4,7 +4,7 @@
 import org.txm.utils.messages.Utf8NLS;
 
 /**
  * CAP UI messages.
  * 
  * @author mdecorde
  * @author sjacquot
@@ -12,6 +12,8 @@
  */
 public class CQPUIMessages extends NLS {
 	
+	private static final String BUNDLE_NAME = "org.txm.searchengine.cqp.rcp.messages.messages"; //$NON-NLS-1$
+	
 	public static String CQPPreferencePage_0;
 	public static String CQPPreferencePage_1;
 	public static String CQPPreferencePage_10;
@@ -25,6 +27,6 @@
 	
 	static {
 		// initialize resource bundle
-		Utf8NLS.initializeMessages(CQPUIMessages.class);
+		Utf8NLS.initializeMessages(BUNDLE_NAME, CQPUIMessages.class);
 	}
 }
@@ -4,7 +4,7 @@
 
 /**
- * CAP UI messages.
+ * CQP UI messages.
  * 
  * @author mdecorde
